==> dl.php?src=linea21_2_5_0.zip: linea21/resources/help.php <==
<?php
/**
 * Resources module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\modules\resources
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 'Resource' module is used by 'Publication' and 'Workshop' modules
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight($mod_inc)) ReloadIndex('admin');
///////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="icon-lifebuoy"></i> <?php echo _t('help','title');?></a>

<div id="aide"><?php if ($todo == 'add_l' || $todo == 'add_m' || $todo == 'add_b') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('resources','add');?></p>
<ul>
	<li><?php echo _t('resources','help_add1');?></li>
	<li><?php echo _t('resources','help_add2');?></li>
	<li><?php echo _t('resources','help_add3');?></li>
</ul>

  <?php }

  if ($todo == 'mod_l' || $todo == 'mod_b' || $todo == 'mod_m') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('resources','mod');?></p>
<ul>
	<li><?php echo _t('resources','help_mod1');?></li>
	<li><?php echo _t('resources','help_mod2');?></li>
	<li><?php echo _t('resources','help_mod3');?></li>
</ul>
    <?php }

    if ($todo == 'sup') {
      ?>

<p class="info"><?php echo _t('help','name');?> : <?php echo _t('resources','sup');?></p>
<ul>
	<li><?php echo _t('resources','help_sup1');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->

==> dl.php?src=linea21_2_8_0.zip: linea21/resources/help.php <==
<?php
/**
 * Resources module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\modules\resources
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 'Resource' module is used by 'Publication' and 'Workshop' modules
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight($mod_inc)) ReloadIndex('admin');
///////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="fa fa-life-ring" aria-hidden="true"></i> <?php echo _t('help','title');?></a>

<div id="aide"><?php if ($todo == 'add_l' || $todo == 'add_m' || $todo == 'add_b') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('resources','add');?></p>
<ul>
	<li><?php echo _t('resources','help_add1');?></li>
	<li><?php echo _t('resources','help_add2');?></li>
	<li><?php echo _t('resources','help_add3');?></li>
</ul>

  <?php }

  if ($todo == 'mod_l' || $todo == 'mod_b' || $todo == 'mod_m') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('resources','mod');?></p>
<ul>
	<li><?php echo _t('resources','help_mod1');?></li>
	<li><?php echo _t('resources','help_mod2');?></li>
	<li><?php echo _t('resources','help_mod3');?></li>
</ul>
    <?php }

    if ($todo == 'sup') {
      ?>

<p class="info"><?php echo _t('help','name');?> : <?php echo _t('resources','sup');?></p>
<ul>
	<li><?php echo _t('resources','help_sup1');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->
